# mbglob

This is a wrapper library for glob.glob.

## Usage

First, install gdwrap by pip.

```bash
pip install mbglob
```

Second, `import` your script.

```py
from mbglob.MbGlob import MbGlob as mbglob
```

And, Init in your script.

```py
data = mbglob(pattern[, recursive=bool])
```

You can see usage sample code below.

`./sample/*.py`
